@@ -9,7 +9,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 our %SPEC;
 
@@ -20,7 +20,7 @@ $SPEC{chain} = {
 
 Currently works for itemfunc only.
 
-See also the `Data::Unixish::Apply` function, which is related.
+See also the <pm:Data::Unixish::Apply> function, which is related.
 
 _
     args => {
@@ -130,7 +130,7 @@ Data::Unixish::chain - Chain several dux functions together
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::chain (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::chain (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -149,13 +149,17 @@ In command-line:
 =head1 FUNCTIONS
 
 
-=head2 chain(%args) -> [status, msg, result, meta]
+=head2 chain
+
+Usage:
+
+ chain(%args) -> [status, msg, result, meta]
 
 Chain several dux functions together.
 
 Currently works for itemfunc only.
 
-See also the C<Data::Unixish::Apply> function, which is related.
+See also the L<Data::Unixish::Apply> function, which is related.
 
 This function is not exported.
 
@@ -197,7 +201,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -213,7 +217,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
