@@ -1,7 +1,7 @@
 package Data::Unixish::num;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '1.55'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '1.56'; # VERSION
 
 use 5.010;
 use locale;
@@ -174,7 +174,7 @@ Data::Unixish::num - Format number
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -193,7 +193,11 @@ In command line:
 =head1 FUNCTIONS
 
 
-=head2 num(%args) -> [status, msg, result, meta]
+=head2 num
+
+Usage:
+
+ num(%args) -> [status, msg, result, meta]
 
 Format number.
 
@@ -274,7 +278,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -290,7 +294,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
