@@ -12,7 +12,7 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 use Text::sprintfn ();
 
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 our %SPEC;
 
@@ -118,7 +118,7 @@ Data::Unixish::sprintfn - Like sprintf, but use sprintfn() from Text::sprintfn
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::sprintfn (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::sprintfn (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,11 @@ In Perl:
 =head1 FUNCTIONS
 
 
-=head2 sprintfn(%args) -> [status, msg, result, meta]
+=head2 sprintfn
+
+Usage:
+
+ sprintfn(%args) -> [status, msg, result, meta]
 
 Like sprintf, but use sprintfn() from Text::sprintfn.
 
@@ -178,7 +182,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -198,7 +202,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
