@@ -1,7 +1,7 @@
 package Data::Unixish::trunc;
 
-our $DATE = '2016-03-16'; # DATE
-our $VERSION = '1.55'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '1.56'; # VERSION
 
 use 5.010;
 use locale;
@@ -90,7 +90,7 @@ Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,11 @@ In command line:
 =head1 FUNCTIONS
 
 
-=head2 trunc(%args) -> [status, msg, result, meta]
+=head2 trunc
+
+Usage:
+
+ trunc(%args) -> [status, msg, result, meta]
 
 Truncate string to a certain column width.
 
@@ -162,7 +166,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -178,7 +182,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
