@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 our %SPEC;
 
@@ -17,8 +17,9 @@ $SPEC{wc} = {
     summary => 'Print newline, word, and byte counts',
     description => <<'_',
 
-Behavior mimics that of the Unix `wc` utility. The order of the counts which is
-returned is always: newline, word, character, byte, maximum line length.
+Behavior mimics that of the Unix <prog:wc> utility. The order of the counts
+which is returned is always: newline, word, character, byte, maximum line
+length.
 
 _
     args => {
@@ -108,7 +109,7 @@ Data::Unixish::wc - Print newline, word, and byte counts
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::wc (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::wc (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -126,12 +127,17 @@ In command line:
 =head1 FUNCTIONS
 
 
-=head2 wc(%args) -> [status, msg, result, meta]
+=head2 wc
+
+Usage:
+
+ wc(%args) -> [status, msg, result, meta]
 
 Print newline, word, and byte counts.
 
-Behavior mimics that of the Unix C<wc> utility. The order of the counts which is
-returned is always: newline, word, character, byte, maximum line length.
+Behavior mimics that of the Unix L<wc> utility. The order of the counts
+which is returned is always: newline, word, character, byte, maximum line
+length.
 
 This function is not exported.
 
@@ -186,7 +192,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -206,7 +212,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
