@@ -7,7 +7,7 @@ use warnings;
 #use Log::Any '$log';
 
 use Data::Unixish::Util qw(%common_args);
-our $VERSION = '1.55'; # VERSION
+our $VERSION = '1.56'; # VERSION
 
 our %SPEC;
 
@@ -16,7 +16,7 @@ $SPEC{yes} = {
     summary => 'Output a string repeatedly until killed',
     description => <<'_',
 
-This is like the Unix `yes` utility.
+This is like the Unix <prog:yes> utility.
 
 _
     args => {
@@ -59,7 +59,7 @@ Data::Unixish::yes - Output a string repeatedly until killed
 
 =head1 VERSION
 
-This document describes version 1.55 of Data::Unixish::yes (from Perl distribution Data-Unixish), released on 2016-03-16.
+This document describes version 1.56 of Data::Unixish::yes (from Perl distribution Data-Unixish), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -74,11 +74,15 @@ In command line:
 =head1 FUNCTIONS
 
 
-=head2 yes(%args) -> [status, msg, result, meta]
+=head2 yes
+
+Usage:
+
+ yes(%args) -> [status, msg, result, meta]
 
 Output a string repeatedly until killed.
 
-This is like the Unix C<yes> utility.
+This is like the Unix L<yes> utility.
 
 This function is not exported.
 
@@ -115,7 +119,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -135,7 +139,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
